﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Syncfusion.JavaScript.DataVisualization.DiagramEnums;
using Syncfusion.JavaScript.DataVisualization.Models;
using Syncfusion.JavaScript.DataVisualization.Models.Diagram;
using System.Web.Script.Serialization;
using System.Text.RegularExpressions;
using Syncfusion.JavaScript.DataVisualization.Models.Collections;
using Label = Syncfusion.JavaScript.DataVisualization.Models.Diagram.Label;
using System.ComponentModel;
using Syncfusion.JavaScript.Shared.Serializer;


namespace SyncfusionMvcApplication11
{
    public partial class DiagramController : Controller
    {
        //
        // GET: /Diagram/
        public ActionResult DiagramFeatures()
        {
            DiagramProperties model = new DiagramProperties();
            model.Height = "600px";
            model.Width = "900px";
            BasicShape newIdea = CreateNode("NewIdea", 150, 60, 300, 60, "New Idea Identified");
            newIdea.Shape = BasicShapes.Path;
            newIdea.PathData = "M 45 220 L 45 220 A 20 30 0 0 1 45 280 L 45 280 A 20 30 0 0 1 45 220 Z";
            BasicShape meeting = CreateNode("Meeting", 150, 60, 300, 150, "Meeting with board");            
            ConnectNode(model, newIdea, meeting, "", false);

            GaugeNode hell = new GaugeNode();
            hell.Name = "hell";
            hell.Width = 100;
            hell.Height = 100;
            hell.OffsetX = 300;
            hell.OffsetY = 200;
            hell.Email = "gs@mail.com";
            hell.Phone = "332222222";
            model.Nodes.Add(hell);

            model.Nodes.Add(newIdea);
            model.Nodes.Add(meeting);            
            model.EnableContextMenu = false;
            model.SnapSettings.SnapConstraints = SnapConstraints.ShowLines | SnapConstraints.SnapToLines;
            //define click event
            model.Click = "click";
            ViewData["diagramModel"] = model;
            return View();
        }
        private BasicShape CreateNode(String name, double width, double height, double offsetx, double offsety, string labelText)
        {
            BasicShape node = new BasicShape();
            node.Name = name;
            Dictionary<string, object> addInfo = new Dictionary<string, object>();
            //add an custom property for the node
            addInfo.Add("email", "gs@gmail.com");
            addInfo.Add("phone", "99898989");
            node.AddInfo = addInfo;
            node.Width = width;
            node.Height = height;
            node.OffsetX = offsetx;
            node.OffsetY = offsety;
            node.FillColor = "#1BA0E2";
            node.BorderColor = "#1BA0E2";
            Syncfusion.JavaScript.DataVisualization.Models.Diagram.Label label = new Syncfusion.JavaScript.DataVisualization.Models.Diagram.Label();
            label.Text = labelText;
            label.FontColor = "white";
            label.Name = name + "_label";
            node.Labels.Add(label);
            return node;
        }
       
        private void ConnectNode(DiagramProperties model, BasicShape targetNode, BasicShape sourceNode, string labelText, bool hasLabel)
        {
            Connector connector = new Connector();
            connector.Name = "line" + model.Connectors.Count + 1;
            connector.Segments = new Collection() { new Segment(Segments.Straight) };
            connector.TargetNode = targetNode.Name;
            connector.SourceNode = sourceNode.Name;
            if (hasLabel)
            {
                Syncfusion.JavaScript.DataVisualization.Models.Diagram.Label label = new Syncfusion.JavaScript.DataVisualization.Models.Diagram.Label();
                label.FontColor = "black";
                label.FillColor = "white";
                label.Text = labelText;
                connector.Labels.Add(label);
            }
            connector.SourceDecorator.Shape = DecoratorShapes.Arrow;
            connector.TargetDecorator.Shape = DecoratorShapes.None;
            model.Connectors.Add(connector);
        }
    }

    public class GaugeNode : Node
    {
        private string email;
        private string phone;
        [JsonProperty("email")]
        [DefaultValue("")]
        public string Email
        {
            get { return email; }
            set { email = value; }
        }
        [JsonProperty("phone")]
        [DefaultValue("")]
        public string Phone
        {
            get { return phone; }
            set { phone = value; }
        } 
    }
}
